<?PHP // $Id$ 
      // pix.php - created with Moodle 1.4.1 (2004083101)


$string['angry'] = 'En colre';
$string['approve'] = 'Approbateur';
$string['biggrin'] = 'Gros sourire';
$string['blackeye'] = 'Oeil tumfi';
$string['blush'] = 'Rouge de gne';
$string['clown'] = 'Clown';
$string['cool'] = 'Cool';
$string['dead'] = 'Mort';
$string['evil'] = 'Dmoniaque';
$string['kiss'] = 'Baiser';
$string['mixed'] = 'Indcis';
$string['parentlanguage'] = 'fr';
$string['sad'] = 'Triste';
$string['shy'] = 'Gn';
$string['sleepy'] = 'Endormi';
$string['smiley'] = 'Souriant';
$string['surprise'] = 'Surpris';
$string['thisdirection'] = 'ltr';
$string['thoughtful'] = 'Pensif';
$string['tongueout'] = 'Langue tire';
$string['wideeyes'] = 'Yeux grands ouverts';
$string['wink'] = 'Clin d\'oeil';

?>
